.. Copyright NTESS. See COPYRIGHT file for details.

   SPDX-License-Identifier: MIT

canary 2025.03.25 release notes
===============================

.. contents::

Authors
-------

* Tim Fuller (95)
* Mario LoPrinzi (8)

A total of 2 authors contributed 103 commits to this release.

Issues closed for 2025.03.25
----------------------------

* `#3 <https://cee-gitlab.sandia.gov/ascic-test-infra/canary/-/issues/3>`__: Support vvtest staging
* `#12 <https://cee-gitlab.sandia.gov/ascic-test-infra/canary/-/issues/12>`__: Empire plugin update
* `#32 <https://cee-gitlab.sandia.gov/ascic-test-infra/canary/-/issues/32>`__: nvtest find does not work in test session
* `#35 <https://cee-gitlab.sandia.gov/ascic-test-infra/canary/-/issues/35>`__: nvtest info should accept more input types
* `#40 <https://cee-gitlab.sandia.gov/ascic-test-infra/canary/-/issues/40>`__: Stages with Custom Test Generators
* `#45 <https://cee-gitlab.sandia.gov/ascic-test-infra/canary/-/issues/45>`__: ctrl-c doesn't properly kill subprocesses
* `#47 <https://cee-gitlab.sandia.gov/ascic-test-infra/canary/-/issues/47>`__: vvtest include breaks with multiple tests
* `#48 <https://cee-gitlab.sandia.gov/ascic-test-infra/canary/-/issues/48>`__: Use pluggy as a plugin manager
* `#49 <https://cee-gitlab.sandia.gov/ascic-test-infra/canary/-/issues/49>`__: Incorrect masking when running a specific stage
* `#50 <https://cee-gitlab.sandia.gov/ascic-test-infra/canary/-/issues/50>`__: Path conflicts running on mounted home directory
* `#51 <https://cee-gitlab.sandia.gov/ascic-test-infra/canary/-/issues/51>`__: add analyze stage to vvt tests
* `#52 <https://cee-gitlab.sandia.gov/ascic-test-infra/canary/-/issues/52>`__: support ctest configurations
* `#53 <https://cee-gitlab.sandia.gov/ascic-test-infra/canary/-/issues/53>`__: curl error not saved on failed cdash upload
* `#54 <https://cee-gitlab.sandia.gov/ascic-test-infra/canary/-/issues/54>`__: merging configurations results in changing a dict in place and an error
* `#55 <https://cee-gitlab.sandia.gov/ascic-test-infra/canary/-/issues/55>`__: Remove directives.stages
* `#56 <https://cee-gitlab.sandia.gov/ascic-test-infra/canary/-/issues/56>`__: add way to rerun tests, regardless of status
* `#57 <https://cee-gitlab.sandia.gov/ascic-test-infra/canary/-/issues/57>`__: add better pathspec help
* `#58 <https://cee-gitlab.sandia.gov/ascic-test-infra/canary/-/issues/58>`__: error splitting batch options
* `#59 <https://cee-gitlab.sandia.gov/ascic-test-infra/canary/-/issues/59>`__: expression filtering broken
* `#60 <https://cee-gitlab.sandia.gov/ascic-test-infra/canary/-/issues/60>`__: Assert in Config.py Breaks Sierra Plugin Nightly
* `#61 <https://cee-gitlab.sandia.gov/ascic-test-infra/canary/-/issues/61>`__: Fix docs
* `#62 <https://cee-gitlab.sandia.gov/ascic-test-infra/canary/-/issues/62>`__: enable directive's when expression doesn't work with parameters

Merge requests for 2025.03.25
-----------------------------

* `!35 <https://cee-gitlab.sandia.gov/ascic-test-infra/canary/-/merge_requests/35>`__: Use pluggy
* `!36 <https://cee-gitlab.sandia.gov/ascic-test-infra/canary/-/merge_requests/36>`__: Resolve "Incorrect masking when running a specific stage"
* `!37 <https://cee-gitlab.sandia.gov/ascic-test-infra/canary/-/merge_requests/37>`__: Resolve "Path conflicts running on mounted home directory"
* `!38 <https://cee-gitlab.sandia.gov/ascic-test-infra/canary/-/merge_requests/38>`__: Update the teardown to keep stdout and stderr files based on names
* `!39 <https://cee-gitlab.sandia.gov/ascic-test-infra/canary/-/merge_requests/39>`__: Update the teardown to keep stdout and stderr files based on names
* `!41 <https://cee-gitlab.sandia.gov/ascic-test-infra/canary/-/merge_requests/41>`__: Fix assert to check inodes instead of the path strings
* `!42 <https://cee-gitlab.sandia.gov/ascic-test-infra/canary/-/merge_requests/42>`__: Update hpc_connect interface
* `!43 <https://cee-gitlab.sandia.gov/ascic-test-infra/canary/-/merge_requests/43>`__: Address work tree comparision in sessions.py
